numpy.testing.Tester
====================

.. currentmodule:: numpy.testing

.. autoclass:: Tester

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Tester.__init__
         Tester.bench
         Tester.prepare_test_args
         Tester.test



   

